"""Tests for the sync2vids.sync module."""

from unittest import TestCase
from ffsync import sync

class TestConsole(TestCase):
    def test_basic(self):
        sync.sync('tests/tests_files/sync.csv', 'tests/tests_files')



#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['ffsync']

package_data = \
{'': ['*']}

install_requires = \
['pandas']

setup(name='ffsync',
      version='0.0.8',
      description='Sync two videos.',
      author='fcatus',
      author_email='f.catus@pm.me',
      url='https://github.com/bchaselab/ffsync',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      python_requires='>=3.6',
     )
